@@ -15,30 +15,20 @@ from skyworker_processor.core.processor import process
 from skyworker_processor.core.config import Config
 
 __project__ = "skyworker_dev_petroleum_price_random"
-__version__ = "0.1.0"
+__version__ = "0.2.0"
 __description__ = 'This processor creates random Time Series of the "Petroleum Price" measurement.'
 __measurements__ = ["Petroleum Price"]
 __time_series__ = {
-    "time_series_1": {
-        "name": "Time Series 1",
-        "description": "Description of time_series_1",
+    "time_series_4": {
+        "name": "Time Series 4",
+        "description": "Description of time_series_4",
     },
 }
 __tags__ = {
-    "tag_1": {
-        "name": "Tag 1",
+    "tag_6": {
+        "name": "Tag 6",
         "type": "number",
-        "description": "Description of tag_1",
-    },
-    "tag_2": {
-        "name": "Tag 2",
-        "type": "string",
-        "description": "Description of tag_3",
-    },
-    "tag_3": {
-        "name": "Tag 3",
-        "type": "bool",
-        "description": "Description of tag_3",
+        "description": "Description of tag_6",
     },
 }
 
@@ -54,4 +44,4 @@ Config.VERSION = __version__
 Config.DESCRIPTION = __description__
 Config.MEASUREMENTS = __measurements__
 Config.INPUT.TIME_SERIES = __time_series__
-Config.INPUT.TAGS = __tags__
+Config.PARAMETERS.TAGS = __tags__
